==> blancoCharacterGroup-0.1.6-src.zip: blancoCharacterGroup/blanco.cs/main/blanco/sample/charactergroup/SampleCharacterGroup.cs <==
// ̃\[XR[h blanco FrameworkɂĎĂ܂B
using System;

namespace blanco.sample.charactergroup
{
    /// <summary>O[ṽTvB̃NX͒PɃTvłBۂ̓ɂ͗p܂B</summary>
    public class SampleCharacterGroup
    {
        /// <summary>O[vɊ܂܂镶ł邩ǂ𔻒肵܂B</summary>
        /// <param name="argCheck">`FbNsB</param>
        /// <returns>O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB</returns>
        public bool Match(char argCheck)
        {
            // No.1
            // :0̕
            // 0x30 (Windows-31J)
            // 0x0030 (UTF-16BE)
            if (argCheck == '0') {
                return true;
            }
            // No.2
            // :1̕
            // 0x31 (Windows-31J)
            // 0x0031 (UTF-16BE)
            if (argCheck == '1') {
                return true;
            }
            // No.3
            // :2̕
            // 0x32 (Windows-31J)
            // 0x0032 (UTF-16BE)
            if (argCheck == '2') {
                return true;
            }
            // No.4
            // :3̕
            // 0x33 (Windows-31J)
            // 0x0033 (UTF-16BE)
            if (argCheck == '3') {
                return true;
            }
            // No.5
            // :4̕
            // 0x34 (Windows-31J)
            // 0x0034 (UTF-16BE)
            if (argCheck == '4') {
                return true;
            }
            // No.6
            // :5̕
            // 0x35 (Windows-31J)
            // 0x0035 (UTF-16BE)
            if (argCheck == '5') {
                return true;
            }
            // No.7
            // :6̕
            // 0x36 (Windows-31J)
            // 0x0036 (UTF-16BE)
            if (argCheck == '6') {
                return true;
            }
            // No.8
            // :7̕
            // 0x37 (Windows-31J)
            // 0x0037 (UTF-16BE)
            if (argCheck == '7') {
                return true;
            }
            // No.9
            // :8̕
            // 0x38 (Windows-31J)
            // 0x0038 (UTF-16BE)
            if (argCheck == '8') {
                return true;
            }
            // No.10
            // :9̕
            // 0x39 (Windows-31J)
            // 0x0039 (UTF-16BE)
            if (argCheck == '9') {
                return true;
            }
            // No.11
            // :VONI[gWJ邱Ƃ̊mFB
            // 0x27 (Windows-31J)
            // 0x0027 (UTF-16BE)
            if (argCheck == '\'') {
                return true;
            }
            // No.12
            // :_uNI[gWJ邱Ƃ̊mFB
            // 0x22 (Windows-31J)
            // 0x0022 (UTF-16BE)
            if (argCheck == '\"') {
                return true;
            }
            // No.13
            // :obNXbVWJ邱Ƃ̊mFB
            // 0x5c (Windows-31J)
            // 0x005c (UTF-16BE)
            if (argCheck == '\\') {
                return true;
            }
            // No.14
            // :JExcelApi 2.6̃IWiłɂĐɁ~ƂēWJłȂB
            // 0x817e (Windows-31J)
            // 0x00d7 (UTF-16BE)
            if (argCheck == '~') {
                return true;
            }
            return false;
        }

        /// <summary>^ꂽ񂪁ASĕO[vɊ܂܂镶ł邩ǂ𔻒肵܂B</summary>
        /// <param name="argCheck">`FbNsB</param>
        /// <returns>SĂ̕O[vɊ܂܂ĂtureBO[vɊ܂܂Ȃ܂܂ĂfalseB</returns>
        public bool MatchAll(string argCheck)
        {
            if (argCheck == null) {
                throw new ArgumentException("\bh[MatchAll]̃p[^[argCheck]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            char[] arrayArg = argCheck.ToCharArray();
            int arraySize = arrayArg.Length;
            for (int index = 0; index < arraySize; index++) {
                if (Match(arrayArg[index]) == false) {
                    return false;
                }
            }
            return true;
        }

        /// <summary>^ꂽ񂪁AO[vɊ܂܂镶ЂƂł܂ł邩ǂ𔻒肵܂B</summary>
        /// <param name="argCheck">`FbNsB</param>
        /// <returns>O[vɊ܂܂Ă镶ЂƂł܂łtureBO[vɊ܂܂镶ЂƂ܂܂ȂꍇfalseB</returns>
        public bool MatchAny(string argCheck)
        {
            if (argCheck == null) {
                throw new ArgumentException("\bh[MatchAny]̃p[^[argCheck]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            char[] arrayArg = argCheck.ToCharArray();
            int arraySize = arrayArg.Length;
            for (int index = 0; index < arraySize; index++) {
                if (Match(arrayArg[index])) {
                    return true;
                }
            }
            return false;
        }
    }
}

==> blancoCharacterGroup-0.2.1-src.zip: blancoCharacterGroup/blanco.cs/main/blanco/sample/charactergroup/SampleCharacterGroup.cs <==
// ̃\[XR[h blanco FrameworkɂĎĂ܂B
using System;

namespace blanco.sample.charactergroup
{
    /// <summary>O[ṽTvB̃NX͒PɃTvłBۂ̓ɂ͗p܂B</summary>
    public class SampleCharacterGroup
    {
        /// <summary>O[vɊ܂܂镶ł邩ǂ𔻒肵܂B</summary>
        /// <param name="argCheck">`FbNsB</param>
        /// <returns>O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB</returns>
        public virtual bool Match(char argCheck)
        {
            // No.1
            // :0̕
            // 0x30 (Windows-31J)
            // 0x0030 (UTF-16BE)
            if (argCheck == '0') {
                return true;
            }
            // No.2
            // :1̕
            // 0x31 (Windows-31J)
            // 0x0031 (UTF-16BE)
            if (argCheck == '1') {
                return true;
            }
            // No.3
            // :2̕
            // 0x32 (Windows-31J)
            // 0x0032 (UTF-16BE)
            if (argCheck == '2') {
                return true;
            }
            // No.4
            // :3̕
            // 0x33 (Windows-31J)
            // 0x0033 (UTF-16BE)
            if (argCheck == '3') {
                return true;
            }
            // No.5
            // :4̕
            // 0x34 (Windows-31J)
            // 0x0034 (UTF-16BE)
            if (argCheck == '4') {
                return true;
            }
            // No.6
            // :5̕
            // 0x35 (Windows-31J)
            // 0x0035 (UTF-16BE)
            if (argCheck == '5') {
                return true;
            }
            // No.7
            // :6̕
            // 0x36 (Windows-31J)
            // 0x0036 (UTF-16BE)
            if (argCheck == '6') {
                return true;
            }
            // No.8
            // :7̕
            // 0x37 (Windows-31J)
            // 0x0037 (UTF-16BE)
            if (argCheck == '7') {
                return true;
            }
            // No.9
            // :8̕
            // 0x38 (Windows-31J)
            // 0x0038 (UTF-16BE)
            if (argCheck == '8') {
                return true;
            }
            // No.10
            // :9̕
            // 0x39 (Windows-31J)
            // 0x0039 (UTF-16BE)
            if (argCheck == '9') {
                return true;
            }
            // No.11
            // :VONI[gWJ邱Ƃ̊mFB
            // 0x27 (Windows-31J)
            // 0x0027 (UTF-16BE)
            if (argCheck == '\'') {
                return true;
            }
            // No.12
            // :_uNI[gWJ邱Ƃ̊mFB
            // 0x22 (Windows-31J)
            // 0x0022 (UTF-16BE)
            if (argCheck == '\"') {
                return true;
            }
            // No.13
            // :obNXbVWJ邱Ƃ̊mFB
            // 0x5c (Windows-31J)
            // 0x005c (UTF-16BE)
            if (argCheck == '\\') {
                return true;
            }
            // No.14
            // :JExcelApi 2.6̃IWiłɂĐɁ~ƂēWJłȂB
            // 0x817e (Windows-31J)
            // 0x00d7 (UTF-16BE)
            if (argCheck == '~') {
                return true;
            }
            return false;
        }

        /// <summary>^ꂽ񂪁ASĕO[vɊ܂܂镶ł邩ǂ𔻒肵܂B</summary>
        /// <param name="argCheck">`FbNsB</param>
        /// <returns>SĂ̕O[vɊ܂܂ĂtureBO[vɊ܂܂Ȃ܂܂ĂfalseB</returns>
        public virtual bool MatchAll(string argCheck)
        {
            if (argCheck == null) {
                throw new ArgumentException("\bh[MatchAll]̃p[^[argCheck]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            char[] arrayArg = argCheck.ToCharArray();
            int arraySize = arrayArg.Length;
            for (int index = 0; index < arraySize; index++) {
                if (Match(arrayArg[index]) == false) {
                    return false;
                }
            }
            return true;
        }

        /// <summary>^ꂽ񂪁AO[vɊ܂܂镶ЂƂł܂ł邩ǂ𔻒肵܂B</summary>
        /// <param name="argCheck">`FbNsB</param>
        /// <returns>O[vɊ܂܂Ă镶ЂƂł܂łtureBO[vɊ܂܂镶ЂƂ܂܂ȂꍇfalseB</returns>
        public virtual bool MatchAny(string argCheck)
        {
            if (argCheck == null) {
                throw new ArgumentException("\bh[MatchAny]̃p[^[argCheck]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            char[] arrayArg = argCheck.ToCharArray();
            int arraySize = arrayArg.Length;
            for (int index = 0; index < arraySize; index++) {
                if (Match(arrayArg[index])) {
                    return true;
                }
            }
            return false;
        }
    }
}
